==> haskell-cprng-aes-0.6.1-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cprng-aes
version: 0.6.1
id: cprng-aes-0.6.1-13mLtCGd2OjIymMmvBgQx1
key: cprng-aes-0.6.1-13mLtCGd2OjIymMmvBgQx1
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cprng-aes
synopsis: Crypto Pseudo Random Number Generator using AES in counter mode.
description:
    Simple crypto pseudo-random-number-generator with really good randomness property.
    .
    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)
    .
    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Random.AESCtr
hidden-modules: Crypto.Random.AESCtr.Internal
abi: 9c09dea25f51c31b4ef6f4729822e734
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cprng-aes-0.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cprng-aes-0.6.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/cprng-aes-0.6.1
hs-libraries: HScprng-aes-0.6.1-13mLtCGd2OjIymMmvBgQx1
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 cipher-aes-0.2.11-6WBeZzAuarp4b4pmaENTJ5
    crypto-random-0.0.9-GFoLybqoqGJ8aoFMcvutKJ
haddock-interfaces: /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html: /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cprng-aes-0.6.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cprng-aes
version: 0.6.1
id: cprng-aes-0.6.1-D34AJFphaIFLlHy3ekn48c
key: cprng-aes-0.6.1-D34AJFphaIFLlHy3ekn48c
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cprng-aes
synopsis: Crypto Pseudo Random Number Generator using AES in counter mode.
description:
    Simple crypto pseudo-random-number-generator with really good randomness property.
    .
    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)
    .
    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Random.AESCtr
hidden-modules: Crypto.Random.AESCtr.Internal
abi: 99f68543e57efa04b38a8f77ca394d46
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cprng-aes-0.6.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/cprng-aes-0.6.1
hs-libraries: HScprng-aes-0.6.1-D34AJFphaIFLlHy3ekn48c
depends:
    base-4.9.1.0 byteable-0.1.1-2lU1pexQSLj1KbNO17UifQ
    bytestring-0.10.8.1 cipher-aes-0.2.11-CWuUzOol4nJJiPDAdcuCVu
    crypto-random-0.0.9-3DweoBAJQgg8tU3kDyICSP
haddock-interfaces: /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html: /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
